@@ -1,7 +1,8 @@
-#' @title sassy: Making R Easier for SAS® Programmers
+#' @title sassy: Making R Easier for Everyone
 #' @encoding UTF-8
 #' @description The \strong{sassy} package is a meta-package that
-#' installs a set of functions that aim to make R easier for programmers
+#' installs a set of functions that aim to make R easier for everyone,
+#' especially programmers
 #' whose primary experience is with SAS® software.
 #' These functions provide the ability to create
 #' data libraries, format catalogs, data dictionaries, a traceable log, and
@@ -20,8 +21,9 @@
 #'   \item {\code{\link[logr]{logr}}:}{ Generate a traceable log.}
 #'   \item {\code{\link[reporter]{reporter}}:}{ Write reports and output
 #'   in text, RTF, and PDF.}
+#'   \item {\code{common}:}{ A set of utility functions
+#'   shared across the \strong{sassy} family of packages.}
 #' }
-#'
 #' @examples
 #' #########################################################
 #' #####         Example: Simple Data Listing          #####
@@ -58,7 +60,7 @@
 #' pth <- file.path(tmp, "output/l_dm.rtf") %>% put()
 #'
 #' # Define report object
-#' rpt <- create_report(pth, output_type = "RTF") %>%
+#' rpt <- create_report(pth, output_type = "RTF", font = "Courier") %>%
 #'   page_header("Sponsor: Company", "Study: ABC") %>%
 #'   titles("Listing 1.0", "SDTM Demographics") %>%
 #'   add_content(tbl, align = "left") %>%
@@ -78,8 +80,12 @@
 #'
 #' # View report
 #' # file.show(pth)
+#'
+#' # View log
+#' # file.show(lgpth)
 #' @docType package
 #' @name sassy
+#' @import common
 #' @import logr
 #' @import fmtr
 #' @import libr
@@ -90,6 +96,7 @@ NULL
 
 .onAttach <- function(...) {
 
+  do.call("library", list("common"))
   do.call("library", list("logr"))
   do.call("library", list("fmtr"))
   do.call("library", list("libr"))
